Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1080)

Unified Diff: mandoline/ui/omnibox/omnibox_application.cc

Issue 1340983002: Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mandoline/ui/omnibox/omnibox_application.cc
diff --git a/mandoline/ui/omnibox/omnibox_application.cc b/mandoline/ui/omnibox/omnibox_application.cc
index 18930e3eb31b1398368524fd7724b7bc11ffe610..c3b42de5737b26fb1ccb783cfeb27189e9639d08 100644
--- a/mandoline/ui/omnibox/omnibox_application.cc
+++ b/mandoline/ui/omnibox/omnibox_application.cc
@@ -26,7 +26,7 @@ namespace mandoline {
////////////////////////////////////////////////////////////////////////////////
// OmniboxImpl
-class OmniboxImpl : public mojo::ViewTreeDelegate,
+class OmniboxImpl : public mus::ViewTreeDelegate,
public views::LayoutManager,
public views::TextfieldController,
public Omnibox {
@@ -37,9 +37,9 @@ class OmniboxImpl : public mojo::ViewTreeDelegate,
~OmniboxImpl() override;
private:
- // Overridden from mojo::ViewTreeDelegate:
- void OnEmbed(mojo::View* root) override;
- void OnConnectionLost(mojo::ViewTreeConnection* connection) override;
+ // Overridden from mus::ViewTreeDelegate:
+ void OnEmbed(mus::View* root) override;
+ void OnConnectionLost(mus::ViewTreeConnection* connection) override;
// Overridden from views::LayoutManager:
gfx::Size GetPreferredSize(const views::View* view) const override;
@@ -59,7 +59,7 @@ class OmniboxImpl : public mojo::ViewTreeDelegate,
scoped_ptr<AuraInit> aura_init_;
mojo::ApplicationImpl* app_;
- mojo::View* root_;
+ mus::View* root_;
mojo::String url_;
views::Textfield* edit_;
mojo::Binding<Omnibox> binding_;
@@ -110,9 +110,9 @@ OmniboxImpl::OmniboxImpl(mojo::ApplicationImpl* app,
OmniboxImpl::~OmniboxImpl() {}
////////////////////////////////////////////////////////////////////////////////
-// OmniboxImpl, mojo::ViewTreeDelegate implementation:
+// OmniboxImpl, mus::ViewTreeDelegate implementation:
-void OmniboxImpl::OnEmbed(mojo::View* root) {
+void OmniboxImpl::OnEmbed(mus::View* root) {
root_ = root;
if (!aura_init_.get()) {
@@ -148,7 +148,7 @@ void OmniboxImpl::OnEmbed(mojo::View* root) {
ShowWindow();
}
-void OmniboxImpl::OnConnectionLost(mojo::ViewTreeConnection* connection) {
+void OmniboxImpl::OnConnectionLost(mus::ViewTreeConnection* connection) {
root_ = nullptr;
}
@@ -190,7 +190,7 @@ bool OmniboxImpl::HandleKeyEvent(views::Textfield* sender,
void OmniboxImpl::GetViewTreeClient(
mojo::InterfaceRequest<mojo::ViewTreeClient> request) {
- mojo::ViewTreeConnection::Create(this, request.Pass());
+ mus::ViewTreeConnection::Create(this, request.Pass());
}
void OmniboxImpl::ShowForURL(const mojo::String& url) {
« no previous file with comments | « mandoline/ui/desktop_ui/browser_window.cc ('k') | mandoline/ui/phone_ui/phone_browser_application_delegate.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698